
#include "B4RDefines.h"

namespace B4R
{
    void B4RA4988::Initialize(int16_t steps,int16_t dir_pin,int16_t step_pin)
    {
       rcs = new (backend) A4988(steps, dir_pin, step_pin);
    };
    void B4RA4988::Initialize1(int16_t steps, int16_t dir_pin, int16_t step_pin, int16_t enable_pin)
    {
       rcs = new (backend) A4988(steps, dir_pin, step_pin, enable_pin);
    };   

    void B4RA4988::Initialize2(int16_t steps, int16_t dir_pin, int16_t step_pin, int16_t ms1_pin, int16_t ms2_pin, int16_t ms3_pin)
    {
       rcs = new (backend) A4988(steps, dir_pin, step_pin, ms1_pin, ms2_pin, ms3_pin);
    };
    void B4RA4988::Initialize3(int16_t steps, int16_t dir_pin, int16_t step_pin, int16_t enable_pin, int16_t ms1_pin, int16_t ms2_pin, int16_t ms3_pin)
    {
       rcs = new (backend) A4988(steps, dir_pin, step_pin, enable_pin, ms1_pin, ms2_pin, ms3_pin);
    };

     void B4RA4988::begin(float rpm, int16_t microsteps)
    {
       rcs->begin(rpm, microsteps);
    };   

    int16_t B4RA4988::setMicrostep(int16_t microsteps)
    {
       return rcs->setMicrostep(microsteps);
    };

    int16_t B4RA4988::getMicrostep()
    {
       return rcs->getMicrostep();
    };

    int16_t B4RA4988::getSteps()
    {
       return rcs->getSteps();
    };

    void B4RA4988::setRPM(float rpm)
    {
       rcs->setRPM(rpm);
    };

    float B4RA4988::getRPM()
    {
       return rcs->getRPM();
    };

    float B4RA4988::getCurrentRPM()
    {
       return rcs->getCurrentRPM();
    };

    void B4RA4988::setSpeedProfile(byte mode, int16_t accel, int16_t decel)
    {  A4988::Mode d ; // = Mode::CONSTANT_SPEED ; 
       switch(mode) {
        case 1  : d = A4988::Mode::LINEAR_SPEED   ;break;
        case 0  : d = A4988::Mode::CONSTANT_SPEED ;break;
        default : d = A4988::Mode::CONSTANT_SPEED ;break;
       }    
       rcs->setSpeedProfile( d, accel, decel);
    };

    void B4RA4988::setSpeedProfile1(ArrayInt* profile)
    { int16_t * p = (int16_t*)profile->data ;
        A4988::Profile d; // = {A4988::Mode::CONSTANT_SPEED,0,0} ; 
        switch(p[0]) {
        case 1  : d.mode = A4988::Mode::LINEAR_SPEED   ;break;
        case 0  : d.mode = A4988::Mode::CONSTANT_SPEED ;break;
        default : d.mode = A4988::Mode::CONSTANT_SPEED ;break; }
        d.accel = p[1] ;  
        d.decel = p[2] ;     
       rcs->setSpeedProfile(d);
    };

    ArrayInt* B4RA4988::getSpeedProfile()
    {
       A4988::Profile d = rcs->getSpeedProfile();
       int16_t p[3] = {0,0,0};
       p[1] = d.accel; p[2] = d.decel ;
       if (d.mode == A4988::Mode::CONSTANT_SPEED) {p[0] = 0;} ;
       if (d.mode == A4988::Mode::LINEAR_SPEED) {p[0] = 1;} ; 
       ArrayByte* arr = CreateStackMemoryObject(ArrayByte);
       arr->data=p;
       arr->length=3;
       return arr; 
    };    

    int16_t B4RA4988::getAcceleration()
    {
       return rcs->getAcceleration();
    };

    int16_t B4RA4988::getDeceleration()
    {
       return rcs->getDeceleration();
    };

    void B4RA4988::move(int32_t steps)
    {
       rcs->move(steps);
    };

    void B4RA4988::rotate(int32_t deg)
    {
       rcs->rotate(deg);
    };

    void B4RA4988::rotate1(int16_t deg)
    {
       rcs->rotate(deg);
    };

    void B4RA4988::rotate2(double deg)
    {
       rcs->rotate(deg);
    };

    void B4RA4988::setEnableActiveState(int16_t state)
    {
       rcs->setEnableActiveState(state);
    };

    void B4RA4988::enable()
    {
       rcs->enable();
    };

    void B4RA4988::disable()
    {
       rcs->disable();
    };

    void B4RA4988::startMove(int32_t steps, int32_t time)
    {
       rcs->startMove(steps, time);
    };

    void B4RA4988::startRotate(int16_t deg)
    {
       rcs->startRotate(deg);
    };

    void B4RA4988::startRotate1(int32_t deg)
    {
       rcs->startRotate(deg);
    };

    void B4RA4988::startRotate2(double deg)
    {
       rcs->startRotate(deg);
    };

    int32_t B4RA4988::nextAction()
    {
       return rcs->nextAction();
    };

    void B4RA4988::startBrake()
    {
       rcs->startBrake();
    };

    int32_t B4RA4988::stop()
    {
       return rcs->stop();
    };

    byte B4RA4988::getCurrentState()
    {
       Byte p = 0 ;
       A4988::State d = rcs-> getCurrentState();
       switch(d) {
        case A4988::State::STOPPED      : p=0 ;break;
        case A4988::State::ACCELERATING : p=1 ;break;
        case A4988::State::CRUISING     : p=2 ;break;
        case A4988::State::DECELERATING : p=3 ;break; }
        return p;
    };

    int32_t B4RA4988::getStepsCompleted()
    {
       return rcs->getStepsCompleted();
    };

    int32_t B4RA4988::getStepsRemaining()
    {
       return rcs->getStepsRemaining();
    };

    int16_t B4RA4988::getDirection()
    {
       return rcs->getDirection();
    };

    int32_t B4RA4988::getTimeForMove(int32_t steps)
    {
       return rcs->getTimeForMove(steps);
    };

    int32_t B4RA4988::calcStepsForRotation(int32_t deg)
    {
       return rcs->calcStepsForRotation(deg);
    };

}

